<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Store Logo');

define('TEXT_LOGO_IMAGE', 'New Logo:');
define('TEXT_FORMAT_AND_LOCATION', 'The store logo must be in PNG format and will be saved as:');

define('SUCCESS_LOGO_UPDATED', 'Success: The store logo has successfully been updated!');

define('ERROR_IMAGES_DIRECTORY_NOT_WRITEABLE', 'Error: The images directory cannot be uploaded to. (<a href="%s">click here to review the directory permissions</a>)');
?>