<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/

define('NAVBAR_TITLE_1', 'My Account');
define('NAVBAR_TITLE_2', 'History');

define('HEADING_TITLE', 'My Order History');

define('TEXT_ORDER_NUMBER', 'Order Number:');
define('TEXT_ORDER_STATUS', 'Order Status:');
define('TEXT_ORDER_DATE', 'Order Date:');
define('TEXT_ORDER_SHIPPED_TO', 'Shipped To:');
define('TEXT_ORDER_BILLED_TO', 'Billed To:');
define('TEXT_ORDER_PRODUCTS', 'Products:');
define('TEXT_ORDER_COST', 'Order Cost:');
define('TEXT_VIEW_ORDER', 'View Order');

define('TEXT_NO_PURCHASES', 'You have not yet made any purchases.');
?>
