<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_TITLE', 'Lastest News');
define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_DESCRIPTION', 'Show the lastest osCommerce News');
define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_DATE', 'Date');
define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_FEED_ERROR', 'Could not connect to the osCommerce News feed. The next attempt will be performed within 24 hours.');
define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_ICON_NEWSLETTER', 'Sign-Up for the osCommerce Newsletter');
define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_ICON_FACEBOOK', 'Become an osCommerce Fan on Facebook');
define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_ICON_TWITTER', 'Follow osCommerce on Twitter');
define('MODULE_ADMIN_DASHBOARD_LATEST_NEWS_ICON_RSS', 'Subscribe to the osCommerce News RSS Feed');
?>
