<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

  define('MODULE_BOXES_SPECIALS_TITLE', 'Specials');
  define('MODULE_BOXES_SPECIALS_DESCRIPTION', 'Show products on special');
  define('MODULE_BOXES_SPECIALS_BOX_TITLE', 'Specials');
?>
