<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

  define('MODULE_PAYMENT_IPAYMENT_ELV_TEXT_TITLE', 'iPayment (ELV)');
  define('MODULE_PAYMENT_IPAYMENT_ELV_TEXT_PUBLIC_TITLE', 'Bank Transfer');
  define('MODULE_PAYMENT_IPAYMENT_ELV_TEXT_DESCRIPTION', '<img src="images/icon_popup.gif" border="0">&nbsp;<a href="https://www.ipayment.de" target="_blank" style="text-decoration: underline; font-weight: bold;">Visit iPayment Website</a>');
  define('MODULE_PAYMENT_IPAYMENT_ELV_ERROR_HEADING', 'There has been an error processing your bank card');
  define('MODULE_PAYMENT_IPAYMENT_ELV_ERROR_MESSAGE', 'Please check your bank card details!');
  define('MODULE_PAYMENT_IPAYMENT_ELV_TEXT_BANK_ACCOUNT_OWNER', 'Bank Account Owner:');
  define('MODULE_PAYMENT_IPAYMENT_ELV_TEXT_BANK_ACCOUNT_NUMBER', 'Bank Account Number:');
  define('MODULE_PAYMENT_IPAYMENT_ELV_TEXT_BANK_CODE', 'Bank Code:');
  define('MODULE_PAYMENT_IPAYMENT_ELV_TEXT_BANK_NAME', 'Bank Name:');
?>
