<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Action Recorder');

define('TABLE_HEADING_MODULE', 'Module');
define('TABLE_HEADING_CUSTOMER', 'Customer');
define('TABLE_HEADING_DATE_ADDED', 'Date');
define('TABLE_HEADING_ACTION', 'Action');

define('TEXT_FILTER_SEARCH', 'Search:');
define('TEXT_ALL_MODULES', '-- All Modules --');
define('TEXT_GUEST', 'Guest');

define('TEXT_INFO_IDENTIFIER', 'Identifier:');
define('TEXT_INFO_DATE_ADDED', 'Date Added:');

define('SUCCESS_EXPIRED_ENTRIES', 'Success: %s expired entries were removed.');
?>