<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Version Checker');

define('TABLE_HEADING_VERSION', 'Version');
define('TABLE_HEADING_RELEASED', 'Release Date');
define('TABLE_HEADING_ACTION', 'Action');

define('TEXT_RELEASE_LINK', 'View Release Annoucement');

define('TITLE_INSTALLED_VERSION', 'Installed Version:');

define('VERSION_RUNNING_LATEST', 'You are running the latest version of osCommerce Online Merchant.');
define('VERSION_UPGRADES_AVAILABLE', 'A new version is available for download! (osCommerce Online Merchant v%s)');

define('ERROR_COULD_NOT_CONNECT', 'Could not connect to the osCommerce website to check for new versions.');
?>