<?php
  define('HTTP_SERVER', 'http://<DOMAIN>');
  define('HTTPS_SERVER', 'https://<SSLSERVER>');
  define('ENABLE_SSL', <SSL>);
  define('HTTP_COOKIE_DOMAIN', '<DOMAIN>');
  define('HTTPS_COOKIE_DOMAIN', '<SSLSERVER>');
  define('HTTP_COOKIE_PATH', '/<INSTALLDIRSLASH>');
  define('HTTPS_COOKIE_PATH', '/<INSTALLDIRSLASH>');
  define('DIR_WS_HTTP_CATALOG', '/<INSTALLDIRSLASH>');
  define('DIR_WS_HTTPS_CATALOG', '/<INSTALLDIRSLASH>');
  define('DIR_WS_IMAGES', 'images/');
  define('DIR_WS_ICONS', DIR_WS_IMAGES . 'icons/');
  define('DIR_WS_INCLUDES', 'includes/');
  define('DIR_WS_BOXES', DIR_WS_INCLUDES . 'boxes/');
  define('DIR_WS_FUNCTIONS', DIR_WS_INCLUDES . 'functions/');
  define('DIR_WS_CLASSES', DIR_WS_INCLUDES . 'classes/');
  define('DIR_WS_MODULES', DIR_WS_INCLUDES . 'modules/');
  define('DIR_WS_LANGUAGES', DIR_WS_INCLUDES . 'languages/');

  define('DIR_WS_DOWNLOAD_PUBLIC', 'pub/');
  define('DIR_FS_CATALOG', '<SCRIPTPATH>/');
  define('DIR_FS_DOWNLOAD', DIR_FS_CATALOG . 'download/');
  define('DIR_FS_DOWNLOAD_PUBLIC', DIR_FS_CATALOG . 'pub/');

  define('DB_SERVER', '<MYSQLHOST>');
  define('DB_SERVER_USERNAME', '<MYSQLUSER>');
  define('DB_SERVER_PASSWORD', '<MYSQLPASS>');
  define('DB_DATABASE', '<MYSQLDB>');
  define('USE_PCONNECT', 'false');
  define('STORE_SESSIONS', 'mysql');
?>