<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

  define('MODULE_BOXES_SEARCH_TITLE', 'Search');
  define('MODULE_BOXES_SEARCH_DESCRIPTION', 'Show search field');
  define('MODULE_BOXES_SEARCH_BOX_TITLE', 'Quick Find');
  define('MODULE_BOXES_SEARCH_BOX_TEXT', 'Use keywords to find the product you are looking for.');
  define('MODULE_BOXES_SEARCH_BOX_ADVANCED_SEARCH', 'Advanced Search');
?>
