<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Tax Classes');

define('TABLE_HEADING_TAX_CLASSES', 'Tax Classes');
define('TABLE_HEADING_ACTION', 'Action');

define('TEXT_INFO_EDIT_INTRO', 'Please make any necessary changes');
define('TEXT_INFO_CLASS_TITLE', 'Tax Class Title:');
define('TEXT_INFO_CLASS_DESCRIPTION', 'Description:');
define('TEXT_INFO_DATE_ADDED', 'Date Added:');
define('TEXT_INFO_LAST_MODIFIED', 'Last Modified:');
define('TEXT_INFO_INSERT_INTRO', 'Please enter the new tax class with its related data');
define('TEXT_INFO_DELETE_INTRO', 'Are you sure you want to delete this tax class?');
define('TEXT_INFO_HEADING_NEW_TAX_CLASS', 'New Tax Class');
define('TEXT_INFO_HEADING_EDIT_TAX_CLASS', 'Edit Tax Class');
define('TEXT_INFO_HEADING_DELETE_TAX_CLASS', 'Delete Tax Class');
?>