<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/

define('NAVBAR_TITLE_1', 'My Account');
define('NAVBAR_TITLE_2', 'Change Password');

define('HEADING_TITLE', 'My Password');

define('MY_PASSWORD_TITLE', 'My Password');

define('SUCCESS_PASSWORD_UPDATED', 'Your password has been successfully updated.');
define('ERROR_CURRENT_PASSWORD_NOT_MATCHING', 'Your Current Password did not match the password in our records. Please try again.');
?>
