<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Reviews');

define('TABLE_HEADING_PRODUCTS', 'Products');
define('TABLE_HEADING_RATING', 'Rating');
define('TABLE_HEADING_DATE_ADDED', 'Date Added');
define('TABLE_HEADING_ACTION', 'Action');
define('TABLE_HEADING_STATUS', 'Status');

define('ENTRY_PRODUCT', 'Product:');
define('ENTRY_FROM', 'From:');
define('ENTRY_DATE', 'Date:');
define('ENTRY_REVIEW', 'Review:');
define('ENTRY_REVIEW_TEXT', '<small><font color="#ff0000"><strong>NOTE:</strong></font></small>&nbsp;HTML is not translated!&nbsp;');
define('ENTRY_RATING', 'Rating:');

define('TEXT_INFO_DELETE_REVIEW_INTRO', 'Are you sure you want to delete this review?');

define('TEXT_INFO_DATE_ADDED', 'Date Added:');
define('TEXT_INFO_LAST_MODIFIED', 'Last Modified:');
define('TEXT_INFO_IMAGE_NONEXISTENT', 'IMAGE DOES NOT EXIST');
define('TEXT_INFO_REVIEW_AUTHOR', 'Author:');
define('TEXT_INFO_REVIEW_RATING', 'Rating:');
define('TEXT_INFO_REVIEW_READ', 'Read:');
define('TEXT_INFO_REVIEW_SIZE', 'Size:');
define('TEXT_INFO_REVIEW_STATUS', 'Review Status:');
define('TEXT_INFO_PRODUCTS_AVERAGE_RATING', 'Average Rating:');

define('TEXT_REVIEW_PUBLISHED', 'Published');
define('TEXT_REVIEW_NOT_PUBLISHED', 'Not Published');

define('TEXT_OF_5_STARS', '%s of 5 Stars!');
define('TEXT_GOOD', '<small><font color="#ff0000"><strong>GOOD</strong></font></small>');
define('TEXT_BAD', '<small><font color="#ff0000"><strong>BAD</strong></font></small>');
define('TEXT_INFO_HEADING_DELETE_REVIEW', 'Delete Review');
?>