<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/

define('NAVBAR_TITLE_1', 'My Account');
define('NAVBAR_TITLE_2', 'Product Notifications');

define('HEADING_TITLE', 'Product Notifications');

define('MY_NOTIFICATIONS_TITLE', 'My Product Notifications');
define('MY_NOTIFICATIONS_DESCRIPTION', 'The product notification list allows you to stay up to date on products you find of interest.<br /><br />To be up to date on all product changes, select <strong>Global Product Notifications</strong>.');

define('GLOBAL_NOTIFICATIONS_TITLE', 'Global Product Notifications');
define('GLOBAL_NOTIFICATIONS_DESCRIPTION', 'Recieve notifications on all available products.');

define('NOTIFICATIONS_TITLE', 'Product Notifications');
define('NOTIFICATIONS_DESCRIPTION', 'To remove a product notification, clear the products checkbox and click on Continue.');
define('NOTIFICATIONS_NON_EXISTING', 'There are currently no products marked to be notified on.<br /><br />To add products to your product notification list, click on the notification link available on the detailed product information page.');

define('SUCCESS_NOTIFICATIONS_UPDATED', 'Your product notifications have been successfully updated.');
?>
