<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

define('WARNING_INSTALL_DIRECTORY_EXISTS', 'Installation directory exists at: ' . DIR_FS_CATALOG . 'install. Please remove this directory for security reasons.');
?>
