<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Cache Control');

define('TABLE_HEADING_CACHE', 'Cache Blocks');
define('TABLE_HEADING_DATE_CREATED', 'Date Created');
define('TABLE_HEADING_ACTION', 'Action');

define('TEXT_FILE_DOES_NOT_EXIST', 'File does not exist');
define('TEXT_CACHE_DIRECTORY', 'Cache Directory:');

define('ERROR_CACHE_DIRECTORY_DOES_NOT_EXIST', 'Error: Cache directory does not exist. Please set this Configuration->Cache.');
define('ERROR_CACHE_DIRECTORY_NOT_WRITEABLE', 'Error: Cache directory is not writeable.');
?>
