<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

  define('MODULE_PAYMENT_MONEYBOOKERS_LSR_TEXT_TITLE', 'Moneybookers - Laser (Ireland)');
  define('MODULE_PAYMENT_MONEYBOOKERS_LSR_TEXT_PUBLIC_TITLE', 'Laser');
  define('MODULE_PAYMENT_MONEYBOOKERS_LSR_TEXT_DESCRIPTION', '<img src="images/icon_popup.gif" border="0">&nbsp;<a href="http://www.moneybookers.com/partners/oscommerce" target="_blank" style="text-decoration: underline; font-weight: bold;">Visit Moneybookers Website</a>');
?>
