<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Zones');

define('TABLE_HEADING_COUNTRY_NAME', 'Country');
define('TABLE_HEADING_ZONE_NAME', 'Zones');
define('TABLE_HEADING_ZONE_CODE', 'Code');
define('TABLE_HEADING_ACTION', 'Action');

define('TEXT_INFO_EDIT_INTRO', 'Please make any necessary changes');
define('TEXT_INFO_ZONES_NAME', 'Zones Name:');
define('TEXT_INFO_ZONES_CODE', 'Zones Code:');
define('TEXT_INFO_COUNTRY_NAME', 'Country:');
define('TEXT_INFO_INSERT_INTRO', 'Please enter the new zone with its related data');
define('TEXT_INFO_DELETE_INTRO', 'Are you sure you want to delete this zone?');
define('TEXT_INFO_HEADING_NEW_ZONE', 'New Zone');
define('TEXT_INFO_HEADING_EDIT_ZONE', 'Edit Zone');
define('TEXT_INFO_HEADING_DELETE_ZONE', 'Delete Zone');
?>