<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

  define('MODULE_SOCIAL_BOOKMARKS_EMAIL_TITLE', 'E-Mail');
  define('MODULE_SOCIAL_BOOKMARKS_EMAIL_DESCRIPTION', 'Share products via e-mail.');
  define('MODULE_SOCIAL_BOOKMARKS_EMAIL_PUBLIC_TITLE', 'Share via E-Mail');
?>
