<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'Tax Rates');

define('TABLE_HEADING_TAX_RATE_PRIORITY', 'Priority');
define('TABLE_HEADING_TAX_CLASS_TITLE', 'Tax Class');
define('TABLE_HEADING_COUNTRIES_NAME', 'Country');
define('TABLE_HEADING_ZONE', 'Zone');
define('TABLE_HEADING_TAX_RATE', 'Tax Rate');
define('TABLE_HEADING_ACTION', 'Action');

define('TEXT_INFO_EDIT_INTRO', 'Please make any necessary changes');
define('TEXT_INFO_DATE_ADDED', 'Date Added:');
define('TEXT_INFO_LAST_MODIFIED', 'Last Modified:');
define('TEXT_INFO_CLASS_TITLE', 'Tax Class Title:');
define('TEXT_INFO_COUNTRY_NAME', 'Country:');
define('TEXT_INFO_ZONE_NAME', 'Zone:');
define('TEXT_INFO_TAX_RATE', 'Tax Rate (%):');
define('TEXT_INFO_TAX_RATE_PRIORITY', 'Tax rates at the same priority are added, others are compounded.<br /><br />Priority:');
define('TEXT_INFO_RATE_DESCRIPTION', 'Description:');
define('TEXT_INFO_INSERT_INTRO', 'Please enter the new tax class with its related data');
define('TEXT_INFO_DELETE_INTRO', 'Are you sure you want to delete this tax rate?');
define('TEXT_INFO_HEADING_NEW_TAX_RATE', 'New Tax Rate');
define('TEXT_INFO_HEADING_EDIT_TAX_RATE', 'Edit Tax Rate');
define('TEXT_INFO_HEADING_DELETE_TAX_RATE', 'Delete Tax Rate');
?>
